/*
    Wn: A Server for the HTTP
    File: wn/extra.h
    Version 1.15.4
    
    Copyright (C) 1996  <by John Franks>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 1, or (at your option)
    any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

*/

/* Any extra headers go here */


#define WN_EXTRA_INIT

#define WN_EXTRA_OPTS

#define WN_EXTRA_SETUP

#ifndef USE_WN_READ
#define WN_read(a,b,c)		read(a,b,c)
#endif
